Documentation
¶
Overview ¶
Package logging provides file logging for reel CLI.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultLogDir ¶
func DefaultLogDir() string
DefaultLogDir returns the default log directory following XDG Base Directory Spec. Uses $XDG_STATE_HOME/reel/logs, defaulting to ~/.local/state/reel/logs.
Types ¶
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger wraps the standard logger with level filtering and file output.
func Setup ¶
Setup creates a new logger that writes to a timestamped log file. Returns nil if logging is disabled (noLog=true). cmdArgs should be os.Args to log the command that was run.
Click to show internal directories.
Click to hide internal directories.